"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConsoleFormat = void 0;
const chalk_1 = __importDefault(require("chalk"));
const lodash_1 = __importDefault(require("lodash"));
const lib_1 = require("../../lib");
const base_format_1 = require("./base-format");
class ConsoleFormat extends base_format_1.BaseFormat {
    constructor(resultBag) {
        super();
        this.resultBag = resultBag;
    }
    process() {
        const results = lodash_1.default.chain(this.resultBag.records)
            .filter(record => record.result === 'bypassed')
            .orderBy(['severity'])
            .groupBy(record => record.messages[0])
            .toPairs()
            .value();
        let output = '';
        for (const [firstMessage, records] of results) {
            output += `${this.formatLevel(records[0].severity)} ${chalk_1.default.whiteBright(firstMessage)} ${chalk_1.default.grey(`(${records.length} payloads bypassed)`)}\r\n`;
            const allTags = lodash_1.default.chain(records.map(record => record.tags)).flatten().uniq().value();
            if (allTags.length > 0) {
                output += `#${allTags}\r\n`;
            }
            output += `\r\n`;
            for (const record of records) {
                output += `${chalk_1.default.yellow(JSON.stringify(record.payload, null, '  '))}\r\n`;
            }
            output += `\r\n`;
        }
        const analytics = lodash_1.default.countBy(this.resultBag.records, record => record.result);
        output += `Blocked attacks   ${analytics['blocked'] || 0}\r\n`;
        output += `Bypassed attacks  ${analytics['bypassed'] || 0}`;
        output += `\r\n`;
        return output;
    }
    formatLevel(level) {
        if (level === lib_1.SeverityLevel.CRITICAL) {
            return chalk_1.default.bgRedBright('CRITICAL');
        }
        if (level === lib_1.SeverityLevel.HIGH) {
            return chalk_1.default.bgRedBright('HIGH');
        }
        if (level === lib_1.SeverityLevel.MEDIUM) {
            return chalk_1.default.bgGreen('MEDIUM');
        }
        if (level === lib_1.SeverityLevel.LOW) {
            return chalk_1.default.bgGreen('LOW');
        }
        if (level === lib_1.SeverityLevel.INFO) {
            return chalk_1.default.bgBlue('INFO');
        }
        return '';
    }
}
exports.ConsoleFormat = ConsoleFormat;
