"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebFormat = void 0;
const lodash_1 = __importDefault(require("lodash"));
const lib_1 = require("../../lib");
const base_format_1 = require("./base-format");
class WebFormat extends base_format_1.BaseFormat {
    constructor(resultBag) {
        super();
        this.resultBag = resultBag;
        this.RAW_TEMPLATE = `
        <!DOCTYPE html>
        <html style="background: #ecf0f1;">
            <head>
                <title>Joi security | results</title>
                <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bulma@0.9.1/css/bulma.min.css" integrity="sha256-WLKGWSIJYerRN8tbNGtXWVYnUM5wMJTXD8eG4NtGcDM=" crossorigin="anonymous">
            </head>
            <body>
                <div class="container is-fluid">
                    <div class="mt-6 content">
                        <h2>Joi security results</h2>
                    </div>
                    <div class="columns">
                        <div class="column is-half">

                            <div class="card">
                                <div class="card-content content">
                                    <h4>Attack categories</h4>
                                    <% for (const [firstMessage, records] of results) { %>
                                        <span class="tag"><%- formatLevel(records[0].severity) %></span>
                                        <a href="#"><%- firstMessage %></a> (<%- records.length %> bypassed) <br>
                                    <% } %>
                                </div>
                            </div>

                        </div>
                    </div>
                </div>
            </body>
        </html>
    `;
    }
    process() {
        const results = lodash_1.default.chain(this.resultBag.records)
            .filter(record => record.result === 'bypassed')
            .orderBy(['severity'])
            .groupBy(record => record.messages[0])
            .toPairs()
            .value();
        return lodash_1.default.template(this.RAW_TEMPLATE)({
            results,
            allRecords: this.resultBag.records,
            formatLevel: this.formatLevel
        });
    }
    formatLevel(level) {
        if (level === lib_1.SeverityLevel.CRITICAL) {
            return 'CRITICAL';
        }
        if (level === lib_1.SeverityLevel.HIGH) {
            return 'HIGH';
        }
        if (level === lib_1.SeverityLevel.MEDIUM) {
            return 'MEDIUM';
        }
        if (level === lib_1.SeverityLevel.LOW) {
            return 'LOW';
        }
        if (level === lib_1.SeverityLevel.INFO) {
            return 'INFO';
        }
        return '';
    }
}
exports.WebFormat = WebFormat;
