"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanSchema = void 0;
const lodash_1 = __importDefault(require("lodash"));
const payload_1 = require("./payload");
const result_bag_1 = require("./result-bag");
function scanSchema(schema, options) {
    const basePayload = payload_1.generatePayload(schema);
    const validMock = basePayload.generateMock();
    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
    const { value, error } = schema.validate(validMock);
    if (error) {
        console.debug(value);
        console.debug(error);
        throw new Error('Expecting generated mock to pass the Joi validation schema but failed');
    }
    const generatedAttacks = basePayload.generateAttacks();
    const resultBag = new result_bag_1.ResultBag();
    for (const attack of generatedAttacks) {
        if (attack.tags && lodash_1.default.intersection(attack.tags, options.ignoreTags).length > 0) {
            continue;
        }
        const { error } = schema.validate(attack.payload);
        resultBag.addResult({
            result: error ? 'blocked' : 'bypassed',
            severity: attack.severity,
            messages: attack.messages,
            payload: attack.payload,
            tags: attack.tags || []
        });
    }
    return resultBag;
}
exports.scanSchema = scanSchema;
